@@ -33,7 +33,14 @@ def check_project(func):
 @click.group()
 @click.pass_context
 def cli(ctx):
-    """Root subcommand for query api functionality"""
+    """Root subcommand for query api functionality.
+
+    This command allows you to run GOR queries against the selected server.
+    Before running a query you must select a project with 'nextcode query project [name]'.
+
+    You must have access to the project in CSA in order to run queries. If needed you can
+    user the 'nextcode csa' command to add yourself to a project, provided you have a CSA
+    admin username and password to give yourself the roles."""
     if ctx.obj.service is None:
         check_profile(ctx)
         ctx.obj.service = ctx.obj.client.service("query")
